==> linm-0.7.5b.tar.gz: linm-0.7.5b/src/ncurses/cmd_editor_imp.h <==
#ifndef __MLS_CMD_EDITOR_IMP_H__
#define __MLS_CMD_EDITOR_IMP_H__

#include "define.h"
#include "mlslocale.h"
#include "mlscfgload.h"
#include "ncurses_panel.h"
#include "ncurses_mcd.h"
#include "ncurses_editor.h"
#include "command.h"
#include "selection.h"

// PluginLoader 때문.
#include "vfsplugin.h"
#include "readerctl.h"

namespace MLS {

class CmdEditorImp:public Configurable
{
private:
	NCurses_Panel*			_pPanel;
	NCurses_Mcd*			_pMcd;
	NCurses_Editor*			_pEditor;

public:
	CmdEditorImp() : _pPanel(NULL), _pMcd(NULL), _pEditor(NULL)
	{
		UpdateConfig();
	}
	~CmdEditorImp()
	{	
		SaveConfig(); 
	}

	void SetPanel(NCurses_Panel* p)		{ _pPanel = p; }
	void SetMcd(NCurses_Mcd* p)			{ _pMcd = p; }
	void SetEditor(NCurses_Editor* p)	{ _pEditor = p; }

	NCurses_Mcd* 	GetMcd()		{ return _pMcd; }	
	NCurses_Panel* 	GetPanel()		{ return _pPanel; }
	NCurses_Editor* GetEditor()		{ return _pEditor; }

	// IConfigurable
	void 	UpdateConfig();
	void 	SaveConfig();

	void	Split();
	void	NextWindow();

	void	Key_Enter();
	void	Key_Left();
	void	Key_Right();
	void	Key_Up();
	void	Key_Down();
	void	Key_Home();
	void	Key_End();
	void	Key_PageUp();
	void	Key_PageDown();
	void	Key_Ins();
	void	Key_Del();
	void	Key_BS();
	void	Key_ESC();

	void	Refresh();

	void	Menu();
	void	Quit();
	
	void	CopyClip();
	void	PasteClip();
	void	CutClip();

	void	Undo();

	void	FileNew();
	void	FileSave();
	void	FileSaveAs();

	void	LineNumberView();

	void	Select()		{ _pEditor->Select();		}
	void	SelectAll()		{ _pEditor->SelectAll();	}

	void	Find() 			{ _pEditor->Find(); }
	void	FindNext() 		{ _pEditor->FindNext(); }
	void	FindPrevious()	{ _pEditor->FindPrevious(); }

	void	Key_Tab()		{ _pEditor->Key_Tab();     }
	void	Key_Untab()		{ _pEditor->Key_Untab();   }

	void	IndentMode()	{ _pEditor->IndentMode(); }
	
	void	GotoLine()		{ _pEditor->GotoLine();  }
	void	GotoFirst()		{ _pEditor->GotoFirst(); }
	void	GotoEnd()		{ _pEditor->GotoEnd();   }

	void	VimView();
}; // class CommandImp

}; // namespace

#endif

==> linm_0.7.6-1.tar.gz: linm-0.7.6/src/ncurses/cmd_editor_imp.h <==
#ifndef __MLS_CMD_EDITOR_IMP_H__
#define __MLS_CMD_EDITOR_IMP_H__

#include "cmd_common_imp.h"

#include "command.h"
#include "selection.h"

// PluginLoader 때문.
#include "vfsplugin.h"
#include "readerctl.h"

namespace MLS {

class CmdEditorImp:public CmdCommonImp, public Configurable
{
public:
	CmdEditorImp() : CmdCommonImp()
	{
		UpdateConfig();
	}
	~CmdEditorImp()
	{	
		SaveConfig(); 
	}

	// IConfigurable
	void 	UpdateConfig();
	void 	SaveConfig();

	void	Split();
	void	NextWindow();

	void	Key_Enter();
	void	Key_Left();
	void	Key_Right();
	void	Key_Up();
	void	Key_Down();
	void	Key_Home();
	void	Key_End();
	void	Key_PageUp();
	void	Key_PageDown();
	void	Key_Ins();
	void	Key_Del();
	void	Key_BS();
	void	Key_ESC();

	void	Refresh();
	void	RefreshAll();

	void	Menu();
	void	Quit();
	
	void	CopyClip();
	void	PasteClip();
	void	CutClip();

	void	Undo();

	void	FileNew();
	void	FileSave();
	void	FileSaveAs();

	void	LineNumberView();

	void	Select()		{ _pEditor->Select();		}
	void	SelectAll()		{ _pEditor->SelectAll();	}

	void	Find() 			{ _pEditor->Find(); }
	void	FindNext() 		{ _pEditor->FindNext(); }
	void	FindPrevious()	{ _pEditor->FindPrevious(); }

	void	Key_Tab()		{ _pEditor->Key_Tab();     }
	void	Key_Untab()		{ _pEditor->Key_Untab();   }

	void	IndentMode()	{ _pEditor->IndentMode(); }
	
	void	GotoLine()		{ _pEditor->GotoLine();  }
	void	GotoFirst()		{ _pEditor->GotoFirst(); }
	void	GotoEnd()		{ _pEditor->GotoEnd();   }

	void	VimView();
	void	MouseUse();
}; // class CommandImp

}; // namespace

#endif
